@@ -140,7 +140,7 @@ class CenterIdentity:
         if not isinstance(user, User):
             user = User.from_dict(user)
         if hash_session_id:
-            session_id = hashlib.sha256(session_id).hexdigest()
+            session_id = hashlib.sha256(session_id.encode()).hexdigest()
         return verify_signature(
             base64.b64decode(signature),
             session_id.encode(),
